@@ -41,7 +41,7 @@
 #include <linux/types.h>
 #include <linux/spi/spidev.h>
 #include <time.h>
-
+#include <math.h>
 #include "mailbox.h"
 #include "clk.h"
 #include "gpio.h"
@@ -1282,3 +1282,23 @@ const char * ws2811_get_return_t_str(const ws2811_return_t state)
 
     return "";
 }
+
+
+void ws2811_set_custom_gamma_factor(ws2811_t *ws2811, double gamma_factor)
+{
+    for (int chan = 0; chan < RPI_PWM_CHANNELS; chan++)
+    {
+        ws2811_channel_t *channel = &ws2811->channel[chan];
+
+        if (channel->gamma)
+        {
+          for(int counter = 0; counter < 256; counter++)
+          {
+
+             channel->gamma[counter] = (gamma_factor > 0)? (int)(pow((float)counter / (float)255.00, gamma_factor) * 255.00 + 0.5) : counter;
+
+          }
+        }
+
+    }
+}
